using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using DVBServices;

namespace skyscraper8.EPGCollectorPort.SkyscraperSide.MediaHighway2
{
	internal interface Mhw2EventHandler
	{
		void OnNonMhw2Traffic(int sourcePid, int sectionTableId, byte trafficType);
		void OnMhw2Channels(int sourcePid, MediaHighway2ChannelSection channelSection);
		void OnMhw2Categories(int sourcePid, MediaHighway2CategorySection categorySection);
		void OnMhw2Titles(int sourcePid, MediaHighway2TitleSection titleSection);
		void OnMhw2Summary(int sourcePid, MediaHighway2SummarySection summarySection);
	}
}
